# ReportType


## Enum

* `TEXT` (value: `'text'`)

* `JSON` (value: `'json'`)

* `PDF` (value: `'pdf'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


